from window import win, extension
from extension import buttonlize

def go(e):
    buttonlize(u,'btllb',command=func)

def func():
    print('click')

a=win()
u=a.u

lb=u.add_label((15,15),text='buttonlized label')[-1]
lb2=u.add_button((15,60),text='buttonlized button',command=print)[-1]

u.addtag_withtag('btllb',lb)
u.addtag_withtag('btllb',lb2)

u.add_button2((15,120),text='buttonlize',command=go)

a.go()



from window import win

def s(e):
    funcs[0](2)
def di(e):
    funcs[1]()
def ac(e):
    funcs[2]()

a=win()
u=a.u
u.add_button((2,5),'选定第三个选项',command=s)
u.add_button((180,5),'禁用',command=di)
u.add_button((250,5),'激活',command=ac)
_,_,_,funcs,_=u.add_radiobutton((5,50),width=200,text='test radio button',choices=('1','2','3','4','5','6'))

a.go()



from window import win

index=-1
def additem(e):
    uixml = funcs.add()[-2]
    uixml.loadxml(onexml)
def deleteitemthis(e):
    funcs.delete(index)
def add10(e):
    for i in range(0,10):
        additem(e)
def deleteitem(e):
    funcs.delete(1)
def deleteitem1(e):
    funcs.delete(0)
def deleteall(e):
    funcs.clear()
def print__(name):
    global index
    index=name
    print(name)
def getnowon(e):
    print(funcs.getsel())
def selectnext(e):
    num = len(funcs.getitems())
    now = funcs.getsel()
    if now < num:
        funcs.select(now+1)

a=win()
u=a.u
funcs=u.add_listview((10,5),height=400,command=print__)[-2]

onexml='''<tinui>
<line>
<title text='listview'></title>
<line>
<label text='列表视图'></label>
</line>
</line>
</tinui>
'''

lvitems=funcs.getitems()
lvcontent=(
    ('BasicTinUI','TinUI框架渲染核心','https://tinui.smart-space.com.cn'),
    ('TinUI','基于tkinter的现代元素控件框架','https://smart-space.com.cn/project/TinUI/index.html'),
    ('CSDN','中文IT技术交流平台','https://www.csdn.net/'),
    ('TinText','新版TinML实现平台','https://tintext.smart-space.com.cn/'),
    ('Smart-Space','个人开发者名称','https://smart-space.com.cn')
    )
for i in range(0,5):
    lvitems[i][2].loadxml(f'''<tinui>
    <line>
    <line>
    <title text='{lvcontent[i][0]}'></title>
    <link text='相关链接' url='{lvcontent[i][2]}'></link>
    </line>
    <line>
    <label text='{lvcontent[i][1]}'></label>
    <button2 text='test'></button2>
    </line>
    </line>
    </tinui>''')

u.add_button((5,420),'添加元素',command=additem)
u.add_button((5,470),'删除元素',command=deleteitemthis)
u.add_button((5,520),'获取选中元素',command=getnowon)
u.add_button((5,570),'选择下一个',command=selectnext)
u.add_button((120,420),'删除第一个元素',command=deleteitem1)
u.add_button((120,470),'删除第二个元素',command=deleteitem)
u.add_button((120,520),'清空元素',command=deleteall)
u.add_button((120,570),'增加十个',command=add10)

a.go()



from window import win

def mnone(e):
    u.add_image((10,40),100,200,'none','LOGO.png')

def mfill(e):
    u.add_image((190,40),100,200,'fill','LOGO.png')

def muniform(e):
    u.add_image((300,40),100,200,'uniform','LOGO.png')


a=win()
u=a.u
u.add_button((10,5),'None',command=mnone)
u.add_button((190,5),'Fill',command=mfill)
u.add_button((350,5),'Uniform',command=muniform)

a.go()



from window import win


def di(e):
    funcs.disable()
def ac(e):
    funcs.active()

a=win()
u=a.u
u.add_button((180,5),'禁用',command=di)
u.add_button((250,5),'激活',command=ac)
_,funcs,_=u.add_radiobox((5,50),content=('1','','2'))

a.go()



from window import win


def callback(mode):
    u.itemconfig(t,text=f'当前模式：{mode}')

def set_default(e):
    select(1)

a=win()
u=a.u
select=u.add_segmentbutton((5,5),content=('节能','均衡','高性能'),command=callback)[-2].select
t=u.add_paragraph((5,100),text='当前模式：节能')
select(0)
u.add_button((5,140),text='默认',command=set_default)

a.go()



from window import win


def disable(e):
    funcs.disable()
def active(e):
    funcs.active()
def on(e):
    funcs.on()
def off(e):
    funcs.off()

a=win()
u=a.u
funcs=u.add_onoff((5,40),command=print)[-2]
u.add_button((5,5),'禁用',command=disable)
u.add_button((80,5),'恢复',command=active)
u.add_button2((160,5),'开启',command=on)
u.add_button2((240,5),'关闭',command=off)

#ctypes.windll.shcore.SetProcessDpiAwareness(1)

a.go()



from typing import Union
from window import *
#winui3
#部分组件无法展示
import winreg


def end():
    bbox=u.bbox('all')
    if bbox==None:
        return (5,5)
    return (5,bbox[3]+10)

def get_dark(): #获取系统亮暗模式设置
    registry = winreg.ConnectRegistry(None, winreg.HKEY_CURRENT_USER)
    reg_keypath = r'SOFTWARE\Microsoft\Windows\CurrentVersion\Themes\Personalize'
    try:
        reg_key = winreg.OpenKey(registry, reg_keypath)
    except FileNotFoundError:
        return False

    for i in range(1024):
        try:
            value_name, value, _ = winreg.EnumValue(reg_key, i)
            if value_name == 'AppsUseLightTheme':
                return value == 0
        except OSError:
            break
    return False

if get_dark():
    class TinUIAuto(TinUITheme):
        '''
        这是TinUI黑暗模式的托管类，不是继承类
        调用时这需要注意文本和数据，样式类参数无需理会
        '''

        def __init__(self,ui:Union[TinUI,BasicTinUI]):
            super().__init__(ui,'tinui-dark-theme')
            self.label='dark'

        def add_button(self,pos,*arg,**kw):
            return self.ui.add_button(pos,fg='#ffffff',bg='#2d2d2d',
                 activefg='#e8e8e8',activebg='#323232',
                 line='#303030',linew=1,activeline='#303030',
                               *arg,**kw)

        def add_checkbutton(self,pos,*arg,**kw):
            return self.ui.add_checkbutton(pos,
                fontfg='#ffffff',fg='#999999',bg='#1d1d1d',
                      activefg='#9c9c9c',activebg='#2a2a2a',
                      onfg='#010101',onbg='#a3a8dc',
                                    *arg,**kw)

        def add_label(self,pos,*arg,**kw):
            return self.ui.add_label(pos,fg='#ffffff',bg='#202020',
                              outline='#202020',*arg,**kw)

        def add_entry(self,pos,*arg,**kw):
            return self.ui.add_entry(pos,fg='#cfcfcf',bg='#2d2d2d',
                activefg='#e6e6e6',activebg='#1f1f1f',
                linew=2,outline='#9a9a9a',onoutline='#b2b8f2',
                              *arg,**kw)

        def add_separate(self,pos,*arg,**kw):
            return self.ui.add_separate(pos,fg='#323232',
                                 *arg,**kw)

        def add_radiobutton(self,pos,*arg,**kw):
            return self.ui.add_radiobutton(pos,
                      fg='#ffffff',bg='#1d1d1d',
                      activefg='#000000',activebg='#b2b8f2',
                                    *arg,**kw)

        def add_link(self,pos,*arg,**kw):
            return self.ui.add_link(pos,fg='#d7d9f9',
               activefg='#d7d9f9',activebg='#2d2d2d',
                                    *arg,**kw)

        def add_waitbar1(self,pos,*arg,**kw):
            return self.ui.add_waitbar1(pos,fg='#b2b8f2',
                                       bg='#202020',okfg='#b2b8f2',bd=5,
                                       *arg,**kw)

        def add_labelframe(self,uids:tuple,*arg,**kw):
            return self.ui.add_labelframe(uids,fg='#ffffff',bg='#272727',
                                          *arg,**kw)

        def add_waitbar2(self,pos,*arg,**kw):
            return self.ui.add_waitbar2(pos,
                        fg='#b2b8f2',bg='#202020',okcolor='#b2b8f2',
                                        *arg,**kw)

        def add_combobox(self,pos,*arg,**kw):
            return self.ui.add_combobox(pos,
                   fg='#cfcfcf',bg='#2d2d2d',
                   activefg='#ffffff',activebg='#393939',
                                        *arg,**kw)

        def add_progressbar(self,pos,*arg,**kw):
            return self.ui.add_progressbar(pos,
                    fg='#9a9a9a',bg='#b2b8f2',back='#202020',
                    fontc='#0000ff',*arg,**kw)

        def add_table(self,pos,*arg,**kw):
            return self.ui.add_table(pos,
                    outline='#9a9a9a',fg='#ffffff',bg='#2d2d2d',
                    headbg='#b2b8f2',*arg,**kw)

        def add_onoff(self,pos,*arg,**kw):
            return self.ui.add_onoff(pos,
                    fg='#cccccc',bg='#1d1d1d',
                    onfg='#000000',onbg='#b2b8f2',
                                     *arg,**kw)

        def add_spinbox(self,pos,*arg,**kw):
            return self.ui.add_spinbox(pos,
                  fg='#ffffff',bg='#2d2d2d',
                  activefg='#b8b8b8',activebg='#303030',
                                       *arg,**kw)

        def add_scalebar(self,pos,*arg,**kw):
            return self.ui.add_scalebar(pos,
                    fg='#b2b8f2',bg='#9a9a9a',activefg='#b2b8f2',
                    buttonbg='#454545',buttonoutline='#303030',
                                        *arg,**kw)

        def add_info(self,pos,*arg,**kw):
            return self.ui.add_info(pos,
               fg='#b2b8f2',bg='#2d2d2d',info_fg='#ffffff',
                                    *arg,**kw)

        def add_menubar(self,uid,*arg,**kw):
            return self.ui.add_menubar(uid,
                fg='#e6e6e6',bg='#323233',
                activefg='#ffffff',activebg='#3d3d3e',*arg,**kw)

        def add_tooltip(self,uid,*arg,**kw):
            return self.ui.add_tooltip(uid,fg='#e8e8e8',bg='#353535',
                                       *arg,**kw)

        def add_waitbar3(self,pos,*arg,**kw):
            return self.ui.add_waitbar3(pos,
                fg='#b2b8f2',bg='#202020',okcolor='#b2b8f2',
                                        *arg,**kw)

        def add_textbox(self,pos,*arg,**kw):
            return self.ui.add_textbox(pos,fg='#ffffff',bg='#2d2d2d',
                  outline='#9a9a9a',onoutline='#b2b8f2',
                                       *arg,**kw)

        def add_scrollbar(self,pos,widget,*arg,**kw):
            return self.ui.add_scrollbar(pos,widget,
                    bg='#2e2e2e',color='#9f9f9f',
                    oncolor='#a0a0a0',*arg,**kw)

        def add_listbox(self,pos,*arg,**kw):
            return self.ui.add_listbox(pos,
                    bg='#2b2b2b',fg='white',activebg='#b4bbea',sel='#465097',
                                       *arg,**kw)

        def add_canvas(self,pos,*arg,**kw):
            return self.ui.add_canvas(pos,
                    outline='#808080',linew=1,
                                      *arg,**kw)

        def add_pipspager(self,pos,*arg,**kw):
            return self.ui.add_pipspager(pos,
                    bg='#202020',fg='#9a9a9a',buttonbg='#303030',
                                         *arg,**kw)

        def add_notebook(self,pos,*arg,**kw):
            return self.ui.add_notebook(pos,
                    color='#202020',fg='#cccccc',bg='#202020',
                    activefg='#cfcfcf',activebg='#2d2d2d',
                    onfg='#ffffff',onbg='#282828',
                                        *arg,**kw)

        def add_ratingbar(self,pos,*arg,**kw):
            return self.ui.add_ratingbar(pos,
                    fg='#cccccc',bg='#202020',
                    onfg='#b2b8f2',onbg='#b2b8f2',
                                         *arg,**kw)

        def add_radiobox(self,pos,*arg,**kw):
            return self.ui.add_radiobox(pos,
                    fontfg='#ffffff',fg='#939393',bg='#2a2a2a',
                    activefg='#959595',activebg='#2a2a2a',
                    onfg='#a3a8dc',onbg='#000000',
                                        *arg,**kw)

        def add_notecard(self,pos,*arg,**kw):
            return self.ui.add_notecard(pos,
                    tfg='#ffffff',tbg='#2b2b2b',fg='#ffffff',
                    bg='#272727',sep='#1d1d1d',
                                        *arg,**kw)

        def add_pivot(self,pos,*arg,**kw):
            return self.ui.add_pivot(pos,
                    fg='#a6a6a6',bg='',
                    activefg='#ffffff',activecolor='#5969e0',
                                     *arg,**kw)

        def add_button2(self,pos,*arg,**kw):
            return self.ui.add_button2(pos,fg='#ffffff',bg='#2d2d2d',
                 activefg='#e8e8e8',activebg='#323232',
                 line='#303030',linew=1,activeline='#303030',
                               *arg,**kw)

        def add_expander(self,pos,*arg,**kw):
            return self.ui.add_expander(pos,
                    tfg='#ffffff',tbg='#2b2b2b',
                    bg='#272727',sep='#1d1d1d',
                                        *arg,**kw)
else:
    class TinUIAuto(TinUITheme):
        '''
        这是TinUI明亮模式的托管类，不是继承类
        调用时这需要注意文本和数据，样式类参数无需理会
        '''

        def __init__(self,ui:Union[TinUI,BasicTinUI]):
            super().__init__(ui,'tinui-light-theme')
            self.label='dark'

        def add_button(self,pos,*arg,**kw):
            return self.ui.add_button(pos,fg='#1b1b1b',bg='#fbfbfb',
                 activefg='#1a1a1a',activebg='#f6f6f6',
                 line='#cccccc',linew=1,activeline='#cccccc',
                               *arg,**kw)

        def add_checkbutton(self,pos,*arg,**kw):
            return self.ui.add_checkbutton(pos,
                fontfg='#1a1a1a',fg='#868686',bg='#ededed',
                      activefg='#868686',activebg='#e5e5e5',
                      onfg='white',onbg='#334ac0',
                                    *arg,**kw)

        def add_label(self,pos,*arg,**kw):
            return self.ui.add_label(pos,fg='#1a1a1a',bg='#f3f3f3',
                                     outline='#f3f3f3',*arg,**kw)

        def add_entry(self,pos,*arg,**kw):
            return self.ui.add_entry(pos,fg='#606060',bg='#fbfbfb',
                activefg='black',activebg='#fbfbfb',
                linew=2,outline='#868686',onoutline='#3041d8',
                              *arg,**kw)

        def add_separate(self,pos,*arg,**kw):
            return self.ui.add_separate(pos,fg='#e5e5e5',
                                 *arg,**kw)

        def add_radiobutton(self,pos,*arg,**kw):
            return self.ui.add_radiobutton(pos,
                      fg='black',bg='white',
                      activefg='white',activebg='#4453db',
                                    *arg,**kw)

        def add_link(self,pos,*arg,**kw):
            return self.ui.add_link(pos,fg='#4f62ca',
               activefg='red',activebg='#eaeaea',
                                    *arg,**kw)

        def add_waitbar1(self,pos,*arg,**kw):
            return self.ui.add_waitbar1(pos,fg='#3041d8',
                                        bg='#f3f3f3',okfg='#3041d8',bd=5,
                                       *arg,**kw)

        def add_labelframe(self,uids:tuple,*arg,**kw):
            return self.ui.add_labelframe(uids,fg='#1a1a1a',bg='#f4f4f4',
                                          *arg,**kw)

        def add_waitbar2(self,pos,*arg,**kw):
            return self.ui.add_waitbar2(pos,
                fg='#334ac0',bg='#f3f3f3',okcolor='#3041d8',
                                        *arg,**kw)

        def add_combobox(self,pos,*arg,**kw):
            return self.ui.add_combobox(pos,
                   fg='#1a1a1a',bg='#fbfbfb',
                   activefg='#1a1a1a',activebg='#ededee',
                                        *arg,**kw)

        def add_progressbar(self,pos,*arg,**kw):
            return self.ui.add_progressbar(pos,
                fg='#868686',bg='#334ac0',back='#f3f3f3',
                      fontc='#79b8f8',*arg,**kw)

        def add_table(self,pos,*arg,**kw):
            return self.ui.add_table(pos,
                    outline='#dadad8',fg='black',bg='white',
                    headbg='#f4f4f2',*arg,**kw)

        def add_onoff(self,pos,*arg,**kw):
            return self.ui.add_onoff(pos,
                    fg='#5a5a5a',bg='#ededed',
                    onfg='#ffffff',onbg='#4453db',
                                     *arg,**kw)

        def add_spinbox(self,pos,*arg,**kw):
            return self.ui.add_spinbox(pos,
                  fg='#1a1a1a',bg='#fbfbfb',
                  activefg='#818181',activebg='#f2f2f2',
                                       *arg,**kw)

        def add_scalebar(self,pos,*arg,**kw):
            return self.ui.add_scalebar(pos,
                fg='#3b50ba',bg='#868686',activefg='#3b50ba',
                buttonbg='#ffffff',buttonoutline='#cccccc',
                                        *arg,**kw)

        def add_info(self,pos,*arg,**kw):
            return self.ui.add_info(pos,
               fg='#0078d4',bg='#f9f9f9',info_fg='#1a1a1a',
                                    *arg,**kw)

        def add_menubar(self,uid,*arg,**kw):
            return self.ui.add_menubar(uid,
                fg='#1a1a1a',bg='#faf8f9',
                activefg='#1a1a1a',activebg='#efefef',*arg,**kw)

        def add_tooltip(self,uid,*arg,**kw):
            return self.ui.add_tooltip(uid,fg='#1a1a1a',bg='#efefef',
                                       *arg,**kw)

        def add_waitbar3(self,pos,*arg,**kw):
            return self.ui.add_waitbar3(pos,
                fg='#3041d8',bg='#f3f3f3',okcolor='#3041d8',
                                        *arg,**kw)

        def add_textbox(self,pos,*arg,**kw):
            return self.ui.add_textbox(pos,fg='#1a1a1a',bg='white',
                  outline='#868686',onoutline='#3041d8',
                                       *arg,**kw)

        def add_scrollbar(self,pos,widget,*arg,**kw):
            return self.ui.add_scrollbar(pos,widget,
                    bg='#f9f9f9',color='#8d8d8d',
                     oncolor='#8a8a8a',*arg,**kw)

        def add_listbox(self,pos,*arg,**kw):
            return self.ui.add_listbox(pos,
                    bg='#f2f2f2',fg='black',activebg='#e9e9e9',sel='#b4bbea',
                                       *arg,**kw)

        def add_canvas(self,pos,*arg,**kw):
            return self.ui.add_canvas(pos,
                    outline='#808080',linew=1,
                                      *arg,**kw)

        def add_pipspager(self,pos,*arg,**kw):
            return self.ui.add_pipspager(pos,
                    bg='#f3f3f3',fg='#868686',buttonbg='#fafafa',
                                         *arg,**kw)

        def add_notebook(self,pos,*arg,**kw):
            return self.ui.add_notebook(pos,
                    color='#f3f3f3',fg='#5d5d5d',bg='#f3f3f3',
                    activefg='#595959',activebg='#eaeaea',
                    onfg='#1a1a1a',onbg='#f9f9f9',
                                        *arg,**kw)

        def add_radiobox(self,pos,*arg,**kw):
            return self.ui.add_radiobox(pos,
                    fontfg='black',fg='#8b8b8b',bg='#ededed',
                    activefg='#898989',activebg='#e5e5e5',
                    onfg='#3041d8',onbg='#ffffff',
                                        *arg,**kw)

        def add_ratingbar(self,pos,*arg,**kw):
            return self.ui.add_ratingbar(pos,
                    fg='#5d5d5d',bg='#f3f3f3',
                    onfg='#3041d8',onbg='#3041d8',
                                         *arg,**kw)

        def add_notecard(self,pos,*arg,**kw):
            return self.ui.add_notecard(pos,
                    tfg='#1b1b1b',tbg='#fbfbfb',fg='#1a1a1a',
                    bg='#f4f4f4',sep='#e5e5e5',
                                        *arg,**kw)

        def add_pivot(self,pos,*arg,**kw):
            return self.ui.add_pivot(pos,
                    fg='#616161',bg='',
                    activefg='#000000',activecolor='#5969e0',
                                     *arg,**kw)

        def add_button2(self,pos,*arg,**kw):
            return self.ui.add_button2(pos,fg='#1b1b1b',bg='#fbfbfb',
                 activefg='#1a1a1a',activebg='#f6f6f6',
                 line='#cccccc',linew=1,activeline='#cccccc',
                               *arg,**kw)

        def add_expander(self,pos,*arg,**kw):
            return self.ui.add_expander(pos,
                    tfg='#1b1b1b',tbg='#fbfbfb',
                    bg='#f4f4f4',sep='#e5e5e5',
                                        *arg,**kw)


r=win()

u=r.u
du=TinUIAuto(u)

if get_dark():
    u['background']='#202020'
else:
    u['background']='#f3f3f3'
x=TinUIXml(du)

du.add_label(end(),text='TinUI Auto Light/Dark Theme',font='微软雅黑 25')
du.add_label(end(),text='2022 By rgzz666',font='微软雅黑 13')
du.add_label(end(),text='It will get you system light/dark settings.',font='微软雅黑 13')
du.add_label(end(),text='Then the theme will be light/dark Automaticlly.',font='微软雅黑 13')
du.add_label(end(),text='It only works on Windows10+',font='微软雅黑 13')
du.add_link(end(),text='My Site',url='http://rgzz.great-site.net')

#button
du.add_button(end(),text='Button')
#checkbox
du.add_checkbutton(end(),text='test checkbutton')
#textblock
du.add_label(end(),text='test label')
#textbox
du.add_entry(end(),text='test entry',width=200)
#appbarseparator
du.add_separate(end(),width=200)
#radiobutton
du.add_radiobutton(end(),250,'test radiobutton',('1','2','3','4','5'))
#hyperlinkbutton
du.add_link(end(),text='test link',url='smart-space.com.cn')
#progressring
du.add_waitbar1(end())
#infobar
labelframey=end()[1]+30
lb1=du.add_button((5,labelframey),text='labelframe button1')[1]
lb2=du.add_button(end(),text='labelframe button2')[-1]
lb3=du.add_button(end(),text='labelframe button3')[-1]
du.add_labelframe((lb1,lb2,lb3),title='labelframe')
#progressbar
du.add_waitbar2(end())
#combobox
du.add_combobox(end(),text='test combobox',content=('1','2','3','4','5'))
#progressbar
du.add_progressbar((end()[0],end()[1]+130))[3](75)
#treeview
du.add_table(end(),
data=[['t1','t2','t3'],['tinui','table','test'],['1','2','3']])
#toggleswitch
du.add_onoff(end())
#numberbutton
du.add_spinbox(end(),data=('1','2','3','4','5'))
#slider
du.add_scalebar(end())
#teachingtip
du.add_info(end(),info_text='info test')
#menubar
u.add_back(end())
l1=du.add_label(end(),text='menubar test label')[-1]
du.add_menubar(l1,
cont=(('test1',print),('test2',print),'-',('test3',print)))
#tooltip
l2=du.add_label(end(),text='tooltip test label')[-1]
du.add_tooltip(l2,text='test tooltip')
#progressbar
du.add_waitbar3(end())
#richeditbox
textx,texty=end()
text=du.add_textbox((textx,texty),linew=2)[0]
#richtextbox
du.add_scrollbar((textx+205,texty),text)
#listbox
du.add_listbox(end(),data=('first','second','third',
'some thing between three and four called bleem','forth','fifth',
'some thins behind five\nwhich we can not find it\nfor-\never'))
#inkcanvas
canvas=du.add_canvas(end())[0]
canvas.create_text((100,20),text='TinUI canvas',font='微软雅黑 12')
canvas.create_line((20,50,180,50),fill='#f3f3f3',width=5)
#pipspager
du.add_pipspager(end(),num=5)
#tabview
ntb=du.add_notebook(end())[-2]
for i in range(1,4):
    ntb.addpage('test'+str(i),'t'+str(i))
ntvdict=ntb.getvdict()
num=1
for i in ntvdict:
    ui=ntvdict[i][0]
    uxml=TinUIXml(TinUIAuto(ui))
    xml=f'''
<tinui><line><button text='这是第{num}个BasicTinUI组件' command='print'></button></line>
<line><label text='TinUI的标签栏视图'></label><label text='每个都是单独页面'></label></line>
</tinui>'''
    uxml.loadxml(xml)
    num+=1
#ratingcontrol
du.add_ratingbar(end())
#radiobutton
du.add_radiobox(end(),command=print)
#expander
du.add_notecard(end())
#pivot
du.add_pivot(end())
#button
du.add_button2(end(),'button2')
#expander
du.add_expander(end())

u.add_back(end())
r.r.title('TinUI Auto Light/Dark Theme')
r.go()



from typing import Union
from tinui import TinUI, BasicTinUI, TinUITheme

class TinUILight(TinUITheme):
    '''
    这是TinUI明亮模式的托管类，不是继承类
    调用时这需要注意文本和数据，样式类参数无需理会
    '''

    def __init__(self,ui:Union[TinUI,BasicTinUI]):
        super().__init__(ui,'tinui-light-theme')
        self.label='light'
        self.ui['background']='#f3f3f3'
    
    def add_title(self,pos,*arg,**kw):
        return self.ui.add_title(pos,*arg,**{
            **{'fg':'#000000'},**kw})

    def add_paragraph(self,pos,*arg,**kw):
        return self.ui.add_paragraph(pos,*arg,**{
            **{'fg':'#000000'},**kw})

    def add_button(self,pos,*arg,**kw):
        return self.ui.add_button(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fbfbfb',
                'activefg':'#1a1a1a','activebg':'#f6f6f6',
                'line':'#cccccc','linew':1,'activeline':'#cccccc'
            },**kw})

    def add_checkbutton(self,pos,*arg,**kw):
        return self.ui.add_checkbutton(pos,*arg,**{
            **{
                'fontfg':'#1a1a1a','fg':'#868686','bg':'#ededed',
                'activefg':'#868686','activebg':'#e5e5e5',
                'onfg':'white','onbg':'#0067C0'
            },**kw})

    def add_label(self,pos,*arg,**kw):
        return self.ui.add_label(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#f3f3f3',
                'outline':'#f3f3f3'
            },**kw})

    def add_entry(self,pos,*arg,**kw):
        return self.ui.add_entry(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fbfbfb',
                'activefg':'#1a1a1a','activebg':'#f6f6f6',
                'onfg':'#000000','onbg':'#ffffff',
                'line':'#e5e5e5','activeline':'#e5e5e5',
                'outline':'#868686','onoutline':'#0067C0','insert':'#000000'
            },**kw})

    def add_separate(self,pos,*arg,**kw):
        return self.ui.add_separate(pos,*arg,**{
            **{'fg':'#e5e5e5'},**kw})


    def add_radiobutton(self,pos,*arg,**kw):
        return self.ui.add_radiobutton(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#f2f2f2',
                'activefg':'#191919','activebg':'#e9e9e9',
            },**kw})

    def add_link(self,pos,*arg,**kw):
        return self.ui.add_link(pos,*arg,**{
            **{
                'fg':'#003E92',
                'activefg':'#001A68','activebg':'#eaeaea',
            },**kw})

    def add_waitbar1(self,pos,*arg,**kw):
        # return self.ui.add_waitbar1(pos,*arg,**{
        #     **{
        #         'fg':'#3041d8',
        #         'bg':'#f3f3f3',
        #         'okfg':'#3041d8',
        #         'bd':5
        #     },**kw})
        ...

    def add_labelframe(self,uids:tuple,*arg,**kw):
        return self.ui.add_labelframe(uids,*arg,**{
            **{
                'fg':'#E5E5E5','bg':'#f4f4f4',
            },**kw})

    def add_waitbar2(self,pos,*arg,**kw):
        # return self.ui.add_waitbar2(pos,*arg,**{
        #     **{
        #         'fg':'#3041d8','bg':'#f3f3f3','okcolor':'#0f7b0f',
        #     },**kw})
        ...

    def add_combobox(self,pos,*arg,**kw):
        return self.ui.add_combobox(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#fbfbfb',
                'outline':'#c8c8c8',
                'activefg':'#1a1a1a','activebg':'#f6f6f6',
                'activeline':'#cccccc',
                'onfg':'#5d5d5d','onbg':'#f5f5f5','online':'#e5e5e5',
                'listfg':'#1a1a1a','listactivefg':'#191919','listactivebg':'#F0F0F0',
                'listonfg':'#5C5C5C','listonbg':'#F3F3F3','listsel':'#F0F0F0',
                'scrollbg':'#f9f9f9','scrollcolor':'#999999','scrollon':'#89898b',
            },**kw})

    def add_progressbar(self,pos,*arg,**kw):
        return self.ui.add_progressbar(pos,*arg,**{
            **{
                'fg':'#868686','bg':'#0067C0','back':'#f3f3f3',
                'fontc':'#79b8f8',
            },**kw})

    def add_table(self,pos,*arg,**kw):
        return self.ui.add_table(pos,*arg,**{
            **{
                'outline':'#dadad8','fg':'black','bg':'white',
                'headbg':'#f4f4f2',
            },**kw})

    def add_onoff(self,pos,*arg,**kw):
        return self.ui.add_onoff(pos,*arg,**{
            **{
                'fg':'#5a5a5a','bg':'#ededed',
                'activefg':'#575757','activebg':'#e5e5e5',
                'onactivefg':'#ffffff','onactivebg':'#1975c5',
                'onfg':'#FFFFFF','onbg':'#0067c0',
            },**kw})

    def add_spinbox(self,pos,*arg,**kw):
        return self.ui.add_spinbox(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fefefe','line':'#e5e5e5',
                'activefg':'#1a1a1a','activebg':'#fafafa',
                'onfg':'#868686','onbg':'#f3f3f3',
                'boxfg':'#5f5f5f','boxbg':'#f9f9f9',
                'boxactivefg':'#5b5b5b','boxactivebg':'#f0f0f0',
            },**kw})

    def add_image(self,pos,*arg,**kw):
        return self.ui.add_image(pos,*arg,**kw)

    def add_scalebar(self,pos,*arg,**kw):
        return self.ui.add_scalebar(pos,*arg,**{
            **{
                'fg':'#0067C0','bg':'#868686','activefg':'#1A76C6',
                'buttonbg':'#ffffff','buttonoutline':'#cccccc',
            },**kw})

    def add_info(self,pos,*arg,**kw):
        # return self.ui.add_info(pos,*arg,**{
        #     **{
        #         'fg':'#0078d4','bg':'#f9f9f9','info_fg':'#1a1a1a',
        #     },**kw})
        ...
    
    def add_menubar(self,uid,*arg,**kw):
        return self.ui.add_menubar(uid,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#f9f9f9','line':'#dfdfdf',
                'activefg':'#191919','activebg':'#f0f0f0','activeline':'#f0f0f0',
                'onfg':'#191919','onbg':'#f3f3f3','online':'#f3f3f3',
            },**kw})

    def add_tooltip(self,uid,*arg,**kw):
        return self.ui.add_tooltip(uid,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#efefef',
            },**kw})

    def add_waitbar3(self,pos,*arg,**kw):
        return self.ui.add_waitbar3(pos,*arg,**{
            **{
                'fg':'#0067C0','bg':'#f3f3f3','okcolor':'#0067C0',
            },**kw})

    def add_textbox(self,pos,*arg,**kw):
        return self.ui.add_textbox(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'white',
                'outline':'#868686','onoutline':'#0067C0',
                'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
            },**kw})

    def add_scrollbar(self,pos,widget,*arg,**kw):
        return self.ui.add_scrollbar(pos,widget,*arg,**{
            **{
                'bg':'#f9f9f9','color':'#8d8d8d',
                'oncolor':'#8a8a8a',
            },**kw})

    def add_listbox(self,pos,*arg,**kw):
        return self.ui.add_listbox(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#f2f2f2',
                'activefg':'#191919','activebg':'#e9e9e9',
                'onfg':'#191919','onbg':'#ececec','sel':'#91C1E6',
                'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
            },**kw})

    # def add_canvas(self,pos,*arg,**kw):
    #     return self.ui.add_canvas(pos,*arg,**{
    #         **{
    #             'outline':'#808080','linew':1,
    #             'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
    #         },**kw})

    def add_pipspager(self,pos,*arg,**kw):
        return self.ui.add_pipspager(pos,*arg,**{
            **{
                'bg':'#f3f3f3','fg':'#868686',
                'buttonfg':'#8a8a8a','buttonbg':'#f9f9f9',
                'activefg':'#5f5f5f','activebg':'#f9f9f9',
                'buttononfg':'#5f5f5f','buttononbg':'#f9f9f9',
            },**kw})

    def add_notebook(self,pos,*arg,**kw):
        return self.ui.add_notebook(pos,*arg,**{
            **{
                'color':'#f3f3f3','fg':'#5d5d5d','bg':'#f3f3f3',
                'activefg':'#595959','activebg':'#eaeaea',
                'onfg':'#1a1a1a','onbg':'#f9f9f9',
                'scrollbg':'#f9f9f9','scrollcolor':'#8d8d8d','scrollon':'#8a8a8a',
            },**kw})
    
    def add_ratingbar(self,pos,*arg,**kw):
        return self.ui.add_ratingbar(pos,*arg,**{
            **{
                'fg':'#5d5d5d','bg':'#f3f3f3',
                'onfg':'#0067C0','onbg':'#0067C0',
            },**kw})

    def add_radiobox(self,pos,*arg,**kw):
        return self.ui.add_radiobox(pos,*arg,**{
            **{
                'fontfg':'black','fg':'#8b8b8b','bg':'#ededed',
                'activefg':'#898989','activebg':'#e5e5e5',
                'onfg':'#0067C0','onbg':'#ffffff',
            },**kw})

    def add_notecard(self,pos,*arg,**kw):
        return self.ui.add_notecard(pos,*arg,**{
            **{
                'tfg':'#1b1b1b','tbg':'#fbfbfb','fg':'#1a1a1a',
                'bg':'#f4f4f4','sep':'#e5e5e5',
            },**kw})

    def add_pivot(self,pos,*arg,**kw):
        return self.ui.add_pivot(pos,*arg,**{
            **{
                'fg':'#616161','bg':'',
                'activefg':'#000000','activecolor':'#0067C0',
            },**kw})

    def add_button2(self,pos,*arg,**kw):
        return self.ui.add_button2(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fbfbfb',
                'activefg':'#1a1a1a','activebg':'#f6f6f6',
                'line':'#cccccc','linew':1,'activeline':'#cccccc',
                'onfg':'#5d5d5d','onbg':'#f5f5f5','online':'#e5e5e5',
            },**kw})
    
    def add_accentbutton(self,pos,*arg,**kw):
        return self.ui.add_accentbutton(pos,*arg,**{
            **{
                'fg':'#FFFFFF','bg':'#0067C0',
                'activefg':'#FFFFFF','activebg':'#1975C5',
                'line':'#1473C5','linew':1,'activeline':'#2B80CA',
                'onfg':'#C2DAEF','onbg':'#3183CA','online':'#3183CA',
            },**kw})
    
    def add_toolbutton(self,pos,*arg,**kw):
        return self.ui.add_toolbutton(pos,*arg,**{
            **{
                'fg':'#1A1A1A','bg':'#F3F3F3',
                'activefg':'#191919','activebg':'#EAEAEA',
                'line':'#F3F3F3','linew':1,'activeline':'#EAEAEA',
                'onfg':'#5A5A5A','onbg':'#EDEDED','online':'#EDEDED',
            },**kw})
    
    def add_warningbutton(self,pos,*arg,**kw):
        return self.ui.add_warningbutton(pos,*arg,**{
            **{
                'fg':'#FFFFFF','bg':'#C42B1C',
                'activefg':'#FFFFFF','activebg':'#E04030',
                'line':"#CF2A1B",'linew':1,'activeline':"#CC4A3E",
                'onfg':"#EFC2C2",'onbg':"#CB3E49",'online':"#D52E3C",
            },**kw})

    def add_expander(self,pos,*arg,**kw):
        return self.ui.add_expander(pos,*arg,**{
            **{
                'tfg':'#1b1b1b','tbg':'#fbfbfb',
                'bg':'#f4f4f4','sep':'#e5e5e5',
                'buttonfg':'#1b1b1b','buttonbg':'#fbfbfb','buttonline':'#fbfbfb',
                'activefg':'#1a1a1a','activebg':'#f2f2f2','activeline':'#f2f2f2',
                'onfg':'#1a1a1a','onbg':'#f5f5f5','online':'#f5f5f5',
            },**kw})

    def add_waitframe(self,pos,*arg,**kw):
        return self.ui.add_waitframe(pos,*arg,**{
            **{
                'fg':'#fbfbfb','bg':'#f6f6f6',
            },**kw})

    def add_listview(self,pos,*arg,**kw):
        return self.ui.add_listview(pos,*arg,**{
            **{
                'bg':'#f3f3f3','activebg':'#eaeaea','oncolor':'#0067C0',
                'scrobg':'#f8f8f8','scroc':'#868686','scrooc':'#898989',
            },**kw})

    def add_treeview(self,pos,*arg,**kw):
        return self.ui.add_treeview(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#f3f3f3',
                'onfg':'#1a1a1a','onbg':'#eaeaea',
                'oncolor':'#0067C0','signcolor':'#8a8a8a',
            },**kw})

    def add_togglebutton(self,pos,*arg,**kw):
        return self.ui.add_togglebutton(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fbfbfb','line':'#cccccc',
                'activefg':'#f3f4fd','activebg':'#0067C0','activeline':'#2B80CA',
            },**kw})
    
    def add_swipecontrol(self,pos,*arg,**kw):
        # return self.ui.add_swipecontrol(pos,*arg,**{
        #     **{
        #         'fg':'#1a1a1a','bg':'#f3f3f3','line':'#fbfbfb',
        #         'data':{'left':({'text':'✔️\nok','fg':'#202020','bg':'#bcbcbc','command':print},),
        #         'right':({'text':'❌\nclose'},)},
        #     },**kw})
        ...
    
    def add_picker(self,pos,*arg,**kw):
        return self.ui.add_picker(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fbfbfb',
                'outline':'#ececec','activefg':'#1b1b1b',
                'activebg':'#f6f6f6','onfg':'#eaecfb','onbg':'#0067C0',
                'buttonfg':'#1a1a1a','buttonbg':'#fbfbfb',
                'buttonactivefg':'#1a1a1a','buttonactivebg':'#f0f0f0',
                'buttononfg':'#1a1a1a','buttononbg':'#f3f3f3',
            },**kw})
    
    def add_menubutton(self,pos,*arg,**kw):
        return self.ui.add_menubutton(pos,*arg,**{
            **{
                'fg':'#1b1b1b','bg':'#fbfbfb','line':'#CCCCCC',
                'activefg':'#1a1a1a','activebg':'#f6f6f6','activeline':'#cccccc',
                'onfg':'#5d5d5d','onbg':'#f5f5f5','online':'#e5e5e5',
                'menuonfg':'#191919','menuonbg':'#f0f0f0','menuonline':'#f0f0f0',
            },**kw})
    
    def add_barbutton(self,pos,*arg,**kw):
        return self.ui.add_barbutton(pos,*arg,**{
            **{
                'fg':'#636363','bg':'#f3f3f3','line':'#f3f3f3',
                'activefg':'#191919','activebg':'#eaeaea','activeline':'#eaeaea',
                'onfg':'#5a5a5a','onbg':'#ededed','online':'#ededed','sepcolor':'#e5e5e5',
            },**kw})

    def add_flyout(self,fid,*arg,**kw):
        return self.ui.add_flyout(fid,*arg,**{
            **{
                'line':'#dcdcdc','bg':'#f9f9f9',
            },**kw})
    
    def add_back(self,pos,*arg,**kw):
        return self.ui.add_back(pos,*arg,**{
            **{
                'fg':'#f3f3f3','bg':'#f3f3f3',
            },**kw})
    
    def add_breadcrumb(self,pos,*arg,**kw):
        return self.ui.add_breadcrumb(pos,*arg,**{
            **{
                'fg':'#1a1a1a','bg':'#f3f3f3','activefg':'#5c5c5c'
            },**kw})
    
    def add_segmentbutton(self,pos,*arg,**kw):
        return self.ui.add_segmentbutton(pos,*arg,**{
            **{
                'fg':'#191919','bg':'#EDEDED',
                'activefg':'#181818','activebg':'#E5E5E5',
                'onbg':'#FAFAFA',
                'line':'#E5E5E5','sign':'#0067C0'
        },**kw})

    def add_navigation(self,pos,*arg,**kw):
        return self.ui.add_navigation(pos,*arg,**{
            **{
                'fg':'#1A1A1A','bg':'#F3F3F3',
                'activefg':'#191919','activebg':'#E9E9E9',
                'onfg':'#191919','onbg':'#E9E9E9','oncolor':'#0067C0'
            },**kw})



'''
TinUI的控件整合展示
考虑到TinUI.py的测试界面比较杂乱，大版本（5.0）中启用该界面展示/测试文件
TinUI.py的测试部分仍然保持最新状态，本文件以及从属文件（./testpage）也会持续更新
'''
import sys
import os
sys.path.append('..')
from TinUI import *
from tkinter import Tk
path=os.path.dirname(os.path.abspath(__file__))

load_menubar=False

def opentutest(e):
    exec(open("tuxmltest.py",encoding='utf-8').read(),{'__file__':os.path.dirname(__file__)+r'\tuxmltest.py'})

def loadcontrol(controlname):
    global load_menubar
    #导入控件说明
    cfile=open("testpage/"+controlname+".xml",mode='r',encoding='utf-8')
    cxml=cfile.read()
    cfile.close()
    displayui.delete('all')
    duixml.clean()

    duixml.funcs["opentutest"] = opentutest
    
    duixml.loadxml(cxml)
    if controlname=='menubar':
        label=duixml.tags['label'][-1]
        displayui.add_menubar(label)
    elif controlname=='notebook':
        notebook=duixml.tags['notebook'][-2]
        for i in range(1,5):
            if i==5:#第五个不可删除:
                notebook.addpage('test'+str(i),'t'+str(i),cancancel=False)
            else:
                notebook.addpage('test'+str(i),'t'+str(i))
    elif controlname=='waitframe':
        waitframe=duixml.tags['waitframe'][-2]
        waitframe.start()
    elif controlname=='breadcrumb':
        bc=duixml.tags['bc'][-2]
        for i in range(1,5):
            bc.add('test'+str(i))
    elif controlname=='TinUIXml':#严格来说，这不是控件，而是TinUI框架的一部分
        pass


window = Tk()

window.iconbitmap('../LOGO.ico')
window.title("TinUI main test")
window.geometry("850x600+5+5")
ui=BasicTinUI(window, bg='#f3f3f3')

ui.pack(fill='both',expand=True)

root=ExpandPanel(ui)
hp=HorizonPanel(ui,spacing=5)
root.set_child(hp)

vp=VerticalPanel(ui,spacing=5)
hp.add_child(vp,200)

t=ui.add_title((0,0),text='TinUI Gallery',anchor='n')
img=ui.add_image((0,0),imgfile='LOGO.png',width=200,height=200,anchor='n')
listbox=ui.add_listbox((0,0),height=340,bg='#f0f0f0',data=('back', 'barbutton', 'breadcrumb', 'button', 'button2', 'checkbutton', 
 'combobox', 'entry', 'expander', 'flyout', 'image', 'label', 'labelframe',
 'link', 'listbox', 'listview', 'menubar', 'menubutton', 'navigation', 'notebook', 'notecard', 
 'onoff', 'paragraph', 'passwordbox', 'picker', 'pipspager', 'pivot', 'progressbar', 
 'radiobox', 'radiobutton', 'ratingbar', 'scalebar', 'scrollbar', 'separate', 
 'spinbox', 'segmentbutton', 'table', 'textbox', 'title', 'togglebutton', 'tooltip', 
 'treeview', 'ui', 'waitbar', 'waitframe','TinUIXml'),command=loadcontrol)[-1]
vp.add_child(t,50)
vp.add_child(img,200)
ep1=ExpandPanel(ui)
ep1.set_child(listbox)
vp.add_child(ep1,200,weight=1)
 
displayui,_,duixml,uid=ui.add_ui((0,0),bg='#F9F9F9',width=610,height=575,scrollbar="True",region='auto')
ep=ExpandPanel(ui,bg='#F9F9F9',padding=(5,5,5,5))
ep.set_child(uid)
hp.add_child(ep,500,weight=1)

def update(e):
    root.update_layout(5,5,e.width-5,e.height-5)
ui.bind('<Configure>',update)

def maintest():
    window.mainloop()

if __name__=='__main__':
    maintest()



from window import win

def flash(e):
    funcs[0]()
def on(e):
    funcs[1]()
def off(e):
    funcs[2]()
def ac(e):
    funcs[4]()
def di(e):
    funcs[3]()

def func(state):
    print('state: '+str(state))

a=win()
u=a.u
u.add_button((2,5),'切换状态',command=flash)
u.add_button((80,5),'选定',command=on)
u.add_button((160,5),'取消选定',command=off)
u.add_button((260,5),'disable',command=di)
u.add_button((340,5),'active',command=ac)
_,_,funcs,_=u.add_checkbutton((2,50),'测试checkbutton',command=func)
a.go()



from window import win


def f(e):
    print('go')

a=win()
xml = a.uixml
xml.funcs['test']=print
xml.loadxml(
'''
<!--TinUIXml编辑-->
<tinui>
<line>
<button text='outside' command='self.funcs["test"]'></button>
    <ui>ui
        <button text='button' command='self.funcs["test"]'></button>
        <button2 text='button2'></button2>
        <line>
            <label text='line1'></label>
        </line>
        <line>
            <label text='line2'></label>
        </line>
    </ui>
</line>
</tinui>

'''
)
xml.tags['ui'][-2].funcs['test']=f


a.go()



from window import win

def dop(cont):
    print(f'输入框内容为：{cont}')

a=win()
u=a.u

u.add_button((5,5),text='one')
u.add_button((55,5),text='two1')
u.add_button((55,40),text='two2')
u.add_button((110,5),text='three')

u.add_entry((5,180),350,'这里用来输入',command=dop)

a.go()
